aboutsummaryrefslogtreecommitdiff
path: root/src/include/taler_exchange_service.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/taler_exchange_service.h')
-rw-r--r--src/include/taler_exchange_service.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/include/taler_exchange_service.h b/src/include/taler_exchange_service.h
index 777053792..eaf9fce4d 100644
--- a/src/include/taler_exchange_service.h
+++ b/src/include/taler_exchange_service.h
@@ -374,9 +374,9 @@ struct TALER_EXCHANGE_Keys
unsigned int rc;
/**
* Set to true if tipping is allowed at this exchange.
*/
- bool tipping_allowed;
+ bool rewards_allowed;
};
@@ -374,9 +374,9 @@ struct TALER_EXCHANGE_Keys
unsigned int rc;
/**
- * Set to true if tipping is allowed at this exchange.
+ * Set to true if rewards are allowed at this exchange.
*/